@@ -31,6 +31,10 @@ class GecoRegisterSerializer(RegisterSerializer):
         if not os.path.exists(projects_dir):
             os.mkdir(projects_dir)
 
+        with open(f"{projects_dir}/.htaccess", "w") as htaccess:
+            htaccess.write('Header set Access-Control-Allow-Origin "*"\nHeader set Access-Control-Allow-Headers "Access-Control-Allow-Headers, Origin,Accept, X-Requested-With, Content-Type, Access-Control-Request-Method, Access-Control-Request-Headers, range')
+
+
         user = super().save(request)
         geco_user = GecoUser(project_dir=projects_dir, user=user)
         geco_user.save()
